@@ -142,8 +142,6 @@ import Data.Word(Word8)
 #ifdef mingw32_HOST_OS
 import qualified Data.ByteString.UTF8 as UTF8
 #else
-import qualified GHC.Foreign as GHC
-import qualified GHC.IO.Encoding as Encoding
 import System.IO.Unsafe (unsafePerformIO)
 #endif
 import System.Environment (getEnv)
@@ -170,17 +168,14 @@ infixr 5  </>
 -- (see `Encoding.getFileSystemEncoding`).
 --
 -- When run on Windows, this encodes as UTF-8.
+-- 
+-- the implementation of this function assumes that the
+-- filesystem encoding will not be changed while the program is running.
 encodeFilePath :: FilePath -> RawFilePath
 #ifdef mingw32_HOST_OS
 encodeFilePath = UTF8.fromString
 #else
-encodeFilePath = B.pack . map (fromIntegral . fromEnum) . encodeFilePath'
-
-{-# NOINLINE encodeFilePath' #-}
-encodeFilePath' :: FilePath -> String
-encodeFilePath' f = unsafePerformIO $ do
-	enc <- Encoding.getFileSystemEncoding
-	GHC.withCString enc f (GHC.peekCString Encoding.char8)
+encodeFilePath = unsafePerformIO . B.fromFilePath
 #endif
 
 -- | Convert from RawFilePath to FilePath
@@ -189,20 +184,17 @@ encodeFilePath' f = unsafePerformIO $ do
 -- (see `Encoding.getFileSystemEncoding`).
 --
 -- When run on Windows, this decodes UTF-8.
+
+-- The implementation of this function assumes that the
+-- filesystem encoding will not be changed while the program is running.
 decodeFilePath :: RawFilePath -> FilePath
 #ifdef mingw32_HOST_OS
 decodeFilePath = UTF8.toString
 #else
-decodeFilePath = decodeFilePath' . map (toEnum . fromIntegral) . B.unpack
-
-{-# NOINLINE decodeFilePath' #-}
-decodeFilePath' :: String -> FilePath
-decodeFilePath' s = unsafePerformIO $ do
-	enc <- Encoding.getFileSystemEncoding
-	GHC.withCString Encoding.char8 s (GHC.peekCString enc)
+{-# NOINLINE decodeFilePath #-}
+decodeFilePath = unsafePerformIO . B.toFilePath
 #endif
 
-
 ---------------------------------------------------------------------
 -- Platform Abstraction Methods (private)
 
